# XY

XY commands are used to plot X-Y data and store its display attributes and to write X-Y data to an ASCII file.

## Create XY Objects in Session

```{eval-rst}
.. autoclass:: abaqus.XY.XYSession.XYSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### XY features for Session

```{eval-rst}
.. autoclass:: abaqus.XY.XYSessionBase.XYSessionBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Area

```{eval-rst}
.. autoclass:: abaqus.XY.Area.Area
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AreaStyle

```{eval-rst}
.. autoclass:: abaqus.XY.AreaStyle.AreaStyle
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Axis

```{eval-rst}
.. autoclass:: abaqus.XY.Axis.Axis
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AxisArray

```{eval-rst}
.. autoclass:: abaqus.XY.AxisArray.AxisArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AxisData

```{eval-rst}
.. autoclass:: abaqus.XY.AxisData.AxisData
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Chart

```{eval-rst}
.. autoclass:: abaqus.XY.Chart.Chart
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DefaultChartOptions

```{eval-rst}
.. autoclass:: abaqus.XY.DefaultChartOptions.DefaultChartOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DefaultPlot

```{eval-rst}
.. autoclass:: abaqus.XY.DefaultPlot.DefaultPlot
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Legend

```{eval-rst}
.. autoclass:: abaqus.XY.Legend.Legend
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LineStyle

```{eval-rst}
.. autoclass:: abaqus.XY.LineStyle.LineStyle
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### QuantityType

```{eval-rst}
.. autoclass:: abaqus.XY.QuantityType.QuantityType
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SymbolStyle

```{eval-rst}
.. autoclass:: abaqus.XY.SymbolStyle.SymbolStyle
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TextStyle

```{eval-rst}
.. autoclass:: abaqus.XY.TextStyle.TextStyle
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Title

```{eval-rst}
.. autoclass:: abaqus.XY.Title.Title
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### writeXYReport

```{eval-rst}
.. automodule:: abaqus.XY.writeXYReport
    :members:
    :special-members: __init__
    :show-inheritance:
```

### XYCurve

```{eval-rst}
.. autoclass:: abaqus.XY.XYCurve.XYCurve
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### XYCurveArray

```{eval-rst}
.. autoclass:: abaqus.XY.XYCurveArray.XYCurveArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### XYData

```{eval-rst}
.. autoclass:: abaqus.XY.XYData.XYData
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### XYPlot

```{eval-rst}
.. autoclass:: abaqus.XY.XYPlot.XYPlot
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

```{eval-rst}
.. autoclass:: abaqus.XY.XYPlotBase.XYPlotBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### XYReportOptions

```{eval-rst}
.. autoclass:: abaqus.XY.XYReportOptions.XYReportOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
